@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -33,9 +33,6 @@ class kde(samba):
     sepFields = "\n"
     reSepFields = re.compile(sepFields)
 
-    def __init__(self, text):
-        samba.__init__(self, text)
-
     def removeSymbolR(self, text):
         """Удаляет первый символ названия переменной в строке
 
