@@ -1346,7 +1346,7 @@ def hide_packages(*packages, **kw):
         else:
             raise PackageError(
                 _("Failed to hide {packages}: {error}").format(
-                    package=",".join(str(x) for x in packages),
+                    packages=",".join(str(x) for x in packages),
                     error=_("package is already hidden")))
 
     makeDirectory(hide_dn)
@@ -1359,6 +1359,8 @@ def hide_packages(*packages, **kw):
                     yield fn
 
     arch_files = list(arch_list())
+    if not arch_files:
+        return
     try:
         arch_files = [x for x in arch_files
                       if path.lexists(pathJoin(prefix, x))]
